==> nextline_rdb-0.6.7.tar.gz: nextline_rdb-0.6.7/src/nextline_rdb/alembic/models/rev_f9a742bb2297/strategies/tests/test_st_run.py <==
from hypothesis import given, settings
from hypothesis import strategies as st
from sqlalchemy import select
from sqlalchemy.orm import selectinload

from nextline_rdb.db import DB
from nextline_rdb.utils import safe_compare as sc
from nextline_rdb.utils.strategies import (
    st_datetimes,
    st_graphql_ints,
    st_none_or,
    st_ranges,
)

from ... import Model, Run
from .. import st_model_run, st_model_script


@given(st.data())
@settings(max_examples=200)
async def test_options(data: st.DataObject) -> None:
    run_no = data.draw(st_none_or(st_graphql_ints(min_value=1)))
    if run_no is None:
        min_run_no, max_run_no = data.draw(st_ranges(st_=st_graphql_ints, min_start=1))
    else:
        min_run_no, max_run_no = None, None

    min_started_at, max_started_at = data.draw(st_ranges(st_=st_datetimes))
    min_ended_at, max_ended_at = data.draw(
        st_ranges(st_=st_datetimes, min_start=min_started_at)
    )

    script = data.draw(st_none_or(st_model_script()))

    generate_traces = data.draw(st.booleans())

    run = data.draw(
        st_model_run(
            run_no=run_no,
            min_run_no=min_run_no,
            max_run_no=max_run_no,
            min_started_at=min_started_at,
            max_started_at=max_started_at,
            min_ended_at=min_ended_at,
            max_ended_at=max_ended_at,
            script=script,
            generate_traces=generate_traces,
        )
    )

    if run_no is not None:
        assert run.run_no == run_no
    else:
        assert sc(min_run_no) <= run.run_no <= sc(max_run_no)

    assert sc(min_started_at) <= sc(run.started_at) <= sc(max_started_at)
    assert sc(min_ended_at) <= sc(run.ended_at) <= sc(max_ended_at)
    assert sc(run.started_at) <= sc(run.ended_at)

    if not run.started_at:
        assert not run.ended_at

    if script is not None:
        assert run.script == script

    traces = run.traces
    prompts = run.prompts
    stdouts = run.stdouts
    if generate_traces:
        assert traces
    else:
        assert not traces
        assert not prompts
        assert not stdouts


@given(run=st_model_run())
async def test_db(run: Run) -> None:
    script = run.script
    traces = run.traces
    prompts = run.prompts
    stdouts = run.stdouts

    async with DB(use_migration=False, model_base_class=Model) as db:
        async with db.session.begin() as session:
            session.add(run)
        async with db.session() as session:
            select_run = select(Run)
            # select_run = select_run.options(
            #     selectinload(Run.script),
            #     selectinload(Run.traces),
            #     selectinload(Run.prompts),
            #     selectinload(Run.stdouts),
            # )
            select_run = select_run.options(selectinload('*'))
            run_ = await session.scalar(select_run)
            assert run_
            session.expunge_all()

    assert repr(run) == repr(run_)
    assert repr(script) == repr(run_.script)
    traces = sorted(traces, key=lambda m: m.id)
    assert repr(traces) == repr(sorted(run_.traces, key=lambda m: m.id))
    prompts = sorted(prompts, key=lambda m: m.id)
    assert repr(prompts) == repr(sorted(run_.prompts, key=lambda m: m.id))
    stdouts = sorted(stdouts, key=lambda m: m.id)
    assert repr(stdouts) == repr(sorted(run_.stdouts, key=lambda m: m.id))

==> nextline_rdb-0.6.10.tar.gz: nextline_rdb-0.6.10/src/nextline_rdb/alembic/models/rev_f9a742bb2297/strategies/tests/test_st_run.py <==
from hypothesis import given, settings
from hypothesis import strategies as st
from sqlalchemy import select
from sqlalchemy.orm import selectinload

from nextline_rdb.db import DB
from nextline_test_utils import safe_compare as sc
from nextline_test_utils.strategies import (
    st_datetimes,
    st_graphql_ints,
    st_none_or,
    st_ranges,
)

from ... import Model, Run
from .. import st_model_run, st_model_script


@given(st.data())
@settings(max_examples=200)
async def test_options(data: st.DataObject) -> None:
    run_no = data.draw(st_none_or(st_graphql_ints(min_value=1)))
    if run_no is None:
        min_run_no, max_run_no = data.draw(st_ranges(st_graphql_ints, min_start=1))
    else:
        min_run_no, max_run_no = None, None

    min_started_at, max_started_at = data.draw(st_ranges(st_datetimes))
    min_ended_at, max_ended_at = data.draw(
        st_ranges(st_datetimes, min_start=min_started_at)
    )

    script = data.draw(st_none_or(st_model_script()))

    generate_traces = data.draw(st.booleans())

    run = data.draw(
        st_model_run(
            run_no=run_no,
            min_run_no=min_run_no,
            max_run_no=max_run_no,
            min_started_at=min_started_at,
            max_started_at=max_started_at,
            min_ended_at=min_ended_at,
            max_ended_at=max_ended_at,
            script=script,
            generate_traces=generate_traces,
        )
    )

    if run_no is not None:
        assert run.run_no == run_no
    else:
        assert sc(min_run_no) <= run.run_no <= sc(max_run_no)

    assert sc(min_started_at) <= sc(run.started_at) <= sc(max_started_at)
    assert sc(min_ended_at) <= sc(run.ended_at) <= sc(max_ended_at)
    assert sc(run.started_at) <= sc(run.ended_at)

    if not run.started_at:
        assert not run.ended_at

    if script is not None:
        assert run.script == script

    traces = run.traces
    prompts = run.prompts
    stdouts = run.stdouts
    if generate_traces:
        assert traces
    else:
        assert not traces
        assert not prompts
        assert not stdouts


@given(run=st_model_run())
async def test_db(run: Run) -> None:
    script = run.script
    traces = run.traces
    prompts = run.prompts
    stdouts = run.stdouts

    async with DB(use_migration=False, model_base_class=Model) as db:
        async with db.session.begin() as session:
            session.add(run)
        async with db.session() as session:
            select_run = select(Run)
            # select_run = select_run.options(
            #     selectinload(Run.script),
            #     selectinload(Run.traces),
            #     selectinload(Run.prompts),
            #     selectinload(Run.stdouts),
            # )
            select_run = select_run.options(selectinload('*'))
            run_ = await session.scalar(select_run)
            assert run_
            session.expunge_all()

    assert repr(run) == repr(run_)
    assert repr(script) == repr(run_.script)
    traces = sorted(traces, key=lambda m: m.id)
    assert repr(traces) == repr(sorted(run_.traces, key=lambda m: m.id))
    prompts = sorted(prompts, key=lambda m: m.id)
    assert repr(prompts) == repr(sorted(run_.prompts, key=lambda m: m.id))
    stdouts = sorted(stdouts, key=lambda m: m.id)
    assert repr(stdouts) == repr(sorted(run_.stdouts, key=lambda m: m.id))
